import argparse
import pandas, re
import numpy as np
import sys

def is_nan(s):
    return np.nan if s.startswith("NaN_") else s

def numeric_value(s):
    m = re.findall(r'.*?_(\d+)', s)
    return int(m[0]) if m else 0

def transform(hmp, p1, p2):
    for row_idx, row in hmp.iterrows():
        hmp.ix[row_idx, row == row[p1]]= 'A'
        hmp.ix[row_idx, row == row[p2]]='B'
    hmp= hmp.applymap(lambda v: 'H' if v in ('M', 'R', 'W', 'S', 'Y', 'K') else v)
    hmp= hmp.drop([p1,p2],axis=1)
    hmp= hmp.reindex(columns=sorted(hmp.columns, key=numeric_value))
    return(hmp)

def main():
    parser= argparse.ArgumentParser(description= "PLUMAGE v. 2.0: pipeline for GBS error correction")

    parser.add_argument('-i', metavar= 'infile', default= sys.stdin, nargs='?', type= argparse.FileType('r'),
                        help= "path/name for data file you want to format for r/qtl, default stdin")

    parser.add_argument('-o', metavar= 'outfile', required= True,
                        help= "path/name for resulting r/qtl formatted file")
    
    parser.add_argument('-p1', required= True, metavar= "parent_1",
                        help= "enter name of parent 1 exactly as it appears in file")

    parser.add_argument('-p2', required= True, metavar= "parent_2",
                        help= "enter name of parent 2 exactly as it appears in file")

    args= parser.parse_args()

    hmp= pandas.read_table(args.i)
    out= transform(hmp, args.p1, args.p2)
    out.to_csv(args.o, sep="\t", index=False, na_rep="NA")

if __name__ == "__main__":
  main()
    
